@@ -12,6 +12,7 @@ import re
 import socket
 from functools import wraps
 from xml.sax.saxutils import escape
+import xml.etree.ElementTree
 import warnings
 
 import requests
@@ -25,7 +26,8 @@ from .data_structures import (
 from .cache import Cache
 from .data_structures_entry import from_didl_string
 from .exceptions import (
-    SoCoSlaveException, SoCoUPnPException, NotSupportedException,
+    SoCoException, SoCoSlaveException, SoCoUPnPException,
+    NotSupportedException,
 )
 from .groups import ZoneGroup
 from .music_library import MusicLibrary
@@ -893,6 +895,13 @@ class SoCo(_SocoSingletonBase):
         ])
 
     def _parse_zone_group_state(self):
+        """Parse zone group state, catching some exceptions."""
+        try:
+            self.__parse_zone_group_state_wrapped()
+        except xml.etree.ElementTree.ParseError as ex:
+            raise SoCoException('Parse error: ' + str(ex))
+
+    def __parse_zone_group_state_wrapped(self):
         """The Zone Group State contains a lot of useful information.
 
         Retrieve and parse it, and populate the relevant properties.
@@ -979,8 +988,10 @@ class SoCo(_SocoSingletonBase):
         # and the set of all members
         self._all_zones.clear()
         self._visible_zones.clear()
-        # With some versions, the response is wrapped in ZoneGroupState
-        tree = tree.find('ZoneGroups') or tree
+        # The response is wrapped in ZoneGroups from Sonos 10.1
+        zonegroups = tree.find('ZoneGroups')
+        if zonegroups is not None:
+            tree = zonegroups
         # Loop over each ZoneGroup Element
         for group_element in tree.findall('ZoneGroup'):
             coordinator_uid = group_element.attrib['Coordinator']
@@ -1118,6 +1129,20 @@ class SoCo(_SocoSingletonBase):
             ('CurrentURIMetaData', '')
         ])
 
+    @staticmethod
+    def is_radio_uri(uri):
+        """bool: Is the URI a stream (not a playlist)."""
+        radio_schemes = (
+            "x-rincon-mp3radio:",
+            "x-sonosapi-stream:",
+            "x-sonosapi-radio:",
+            "x-sonosapi-hls:",
+            "hls-radio:",
+            "x-rincon-stream:",
+            "aac:",
+        )
+        return uri.startswith(radio_schemes)
+
     @property
     def is_playing_radio(self):
         """bool: Is the speaker playing radio?"""
@@ -1125,8 +1150,7 @@ class SoCo(_SocoSingletonBase):
             ('InstanceID', 0),
             ('Channel', 'Master')
         ])
-        track_uri = response['TrackURI']
-        return re.match(r'^x-rincon-mp3radio:', track_uri) is not None
+        return self.is_radio_uri(response['TrackURI'])
 
     @property
     def is_playing_line_in(self):
