@@ -22,7 +22,7 @@ class SoCoPlugin(object):
 
     def __init__(self, soco):
         cls = self.__class__.__name__
-        _LOG.info('Initializing SoCo plugin %s', cls)
+        _LOG.debug('Initializing SoCo plugin %s', cls)
         self.soco = soco
 
     @property
@@ -34,7 +34,7 @@ class SoCoPlugin(object):
     def from_name(cls, fullname, soco, *args, **kwargs):
         """Instantiate a plugin by its full name."""
 
-        _LOG.info('Loading plugin %s', fullname)
+        _LOG.debug('Loading plugin %s', fullname)
 
         parts = fullname.split('.')
         modname = '.'.join(parts[:-1])
@@ -43,6 +43,6 @@ class SoCoPlugin(object):
         mod = importlib.import_module(modname)
         class_ = getattr(mod, clsname)
 
-        _LOG.info('Loaded class %s', class_)
+        _LOG.debug('Loaded class %s', class_)
 
         return class_(soco, *args, **kwargs)
