@@ -461,7 +461,7 @@ class Service(object):
             return result
         # Cache miss, so go ahead and make a network call
         headers, body = self.build_command(action, args)
-        log.info("Sending %s %s to %s", action, args, self.soco.ip_address)
+        log.debug("Sending %s %s to %s", action, args, self.soco.ip_address)
         log.debug("Sending %s, %s", headers, prettify(body))
         # Convert the body to bytes, and send it.
         try:
@@ -469,14 +469,14 @@ class Service(object):
                 self.base_url + self.control_url,
                 headers=headers,
                 data=body.encode('utf-8'),
-                timeout=3,
+                timeout=20,
             )
-        except requests.exceptions.RequestException:
-            raise SoCoException('Connection error')
+        except requests.exceptions.RequestException as ex:
+            raise SoCoException('Connection error: ' + str(ex))
 
         log.debug("Received %s, %s", response.headers, response.text)
         status = response.status_code
-        log.info(
+        log.debug(
             "Received status %s from %s", status, self.soco.ip_address)
         if status == 200:
             # The response is good. Get the output params, and return them.
@@ -666,7 +666,8 @@ class Service(object):
         ns = '{urn:schemas-upnp-org:service-1-0}'
         # get the scpd body as bytes, and feed directly to elementtree
         # which likes to receive bytes
-        scpd_body = requests.get(self.base_url + self.scpd_url).content
+        scpd_body = requests.get(
+            self.base_url + self.scpd_url, timeout=10).content
         tree = XML.fromstring(scpd_body)
         # parse the state variables to get the relevant variable types
         vartypes = {}
@@ -730,7 +731,8 @@ class Service(object):
 
         # pylint: disable=invalid-name
         ns = '{urn:schemas-upnp-org:service-1-0}'
-        scpd_body = requests.get(self.base_url + self.scpd_url).text
+        scpd_body = requests.get(
+            self.base_url + self.scpd_url, timeout=10).text
         tree = XML.fromstring(scpd_body.encode('utf-8'))
         # parse the state variables to get the relevant variable types
         statevars = tree.findall('{}stateVariable'.format(ns))
